@@ -1,7 +1,9 @@
 import React from 'react';
 import ReactDOM from "react-dom";
 
+import App from './App'
+
 ReactDOM.render(
-  <h1>Hello, from react!</h1>,
+  <App/>,
   document.getElementById('root')
 );
\ No newline at end of file
